@@ -3,9 +3,10 @@ use 5.6.0;
 use strict;
 use warnings;
 
+use lib 'lib';
 use lib 't/lib';
 
-my $base = 'http://localhost';
+my $host = 'http://localhost';
 my $content_type = [ 'Content-Type', 'application/x-www-form-urlencoded' ];
 
 use RestTest;
@@ -14,7 +15,6 @@ use Test::More tests => 4;
 use Test::WWW::Mechanize::Catalyst 'RestTest';
 use HTTP::Request::Common;
 use JSON::Syck;
-no warnings 'UNIVERSAL::isa';
 
 my $mech = Test::WWW::Mechanize::Catalyst->new;
 ok(my $schema = DBICTest->init_schema(), 'got schema');
@@ -22,7 +22,7 @@ ok(my $schema = DBICTest->init_schema(), 'got schema');
 my $track = $schema->resultset('Track')->first;
 my %original_cols = $track->get_columns;
 
-my $track_delete_url = "$base/api/rest/track/" . $track->id;
+my $track_delete_url = "$host/api/rest/track/" . $track->id;
 
 {
   my $req = HTTP::Request->new( DELETE => $track_delete_url );
