@@ -1,10 +1,12 @@
-package RestTest::Controller::API::REST::Producer;
+package #hide from Pause
+	RestTest::Controller::API::REST::Producer;
 
 use strict;
 use warnings;
-use base qw/RestTest::ControllerBase::REST/;
 use JSON::Syck;
 
+use parent qw/RestTest::ControllerBase::REST/;
+
 __PACKAGE__->config(
     action                  =>  { setup => { PathPart => 'producer', Chained => '/api/rest/rest_base' } },
                                 # define parent chain action and partpath
