@@ -2,7 +2,8 @@ package RestTest::ControllerBase::REST;
 
 use strict;
 use warnings;
-use base qw/Catalyst::Controller::DBIC::API::REST/;
+
+use parent qw/Catalyst::Controller::DBIC::API::REST/;
 
 sub create :Private {
 my ($self, $c) = @_;
